@@ -1,4 +1,6 @@
 import os, sys, json, random, platform, eventlet, time, re, pyproxify
+import itertools
+import threading
 from ua_headers import ua
 eventlet.monkey_patch()
 
@@ -8,7 +10,7 @@ lgreen = '\033[92m'
 clear = '\033[0m'
 bold = '\033[01m'
 cyan = '\033[96m'
-version = "1.1.4"
+version = "1.1.6"
 global log
 global anon
 anon = "tor"
@@ -179,7 +181,7 @@ class ip:
         print(a, "└ "+url[7:] + " : " + str(ip))
     def proxy(data=False):
         if data:
-           proxy_list = pyproxify.fetch(count=10, google=True, https=True)
+           proxy_list = pyproxify.fetch(count=7, google=True, https=True)
            proxy = []
            for item in proxy_list:
               ip = item["ip"]
@@ -187,6 +189,19 @@ class ip:
               proxy.append(ip+":"+port)
            return proxy
         else:
+           done = False
+           def animate():
+               for c in itertools.cycle(["⢿", "⣻", "⣽", "⣾", "⣷", "⣯", "⣟", "⡿"]):
+                   if done:
+                       break
+                   sys.stdout.write('\r\x1B[32mParsing proxy ' + c + '\x1B[37m')
+                   sys.stdout.flush()
+                   time.sleep(0.07)
+               sys.stdout.write('\r')
+           t = threading.Thread(target=animate)
+           t.start()
+           time.sleep(2)
+           done = True
            proxy_list = pyproxify.fetch(count=3, google=True, https=True)
            for item in proxy_list:
               ip = item["ip"]
@@ -204,6 +219,26 @@ class ip:
               print("Checked    : "+last)
               print("Anonymity  : "+anonymity)
               print(" ")
+class check:
+    def proxy(ip, port):
+        import requests
+        proxies = {"http":"http://"+ip+":"+port}
+        headers = {"User-Agent": ua.windows()}
+        info = requests.get("https://ipapi.co/"+ip+"/json/", headers=headers).json()
+        try:
+            with requests.Session() as p:
+                p.proxies.update(proxies)
+                http = p.get("http://api.ipify.org", headers=headers).text
+                print("Proxy    : Online")
+        except:
+            print("Proxy    : Offline")
+        print("Asn      : "+info["asn"])
+        print("Org      : "+info["org"])
+        print("City     : "+info["city"])
+        print("Country  : "+info["country_name"])
+        print("Region   : "+info["region"])
+        print("Network  : "+info["network"])
+        print("Version  : "+info["version"])
 
 class inquiry:
     def get(*args, **kwargs):
@@ -296,8 +331,30 @@ class inquiry:
                              return get
                  except:
                      return '\033[91m403 Website refused to connect\x1B[37m'
+        elif anon == "web":
+            try:
+                import requests
+                if log:
+                    print("[15%] Using web method")
+                url = " ".join([str(m) for m in args])
+                apis = ["4126596c0e563916f96dcf86ec00c269", "da70cc3727c1de7822f28902916ceb81", "19f75e81ed33f56c6ef5c09f22bf87f0"]
+                if log:
+                    print("[30%] Connecting to web")
+                    print("[65%] Processing to get")
+                key = random.choice(apis)
+                paste = "https://api.scraperapi.com?api_key="+key+"&url="+url
+                if log:
+                    print("[90%] Requests get URL")
+                get = requests.get(paste, headers={"User-Agent": ua.linux()})
+                if log:
+                    print("[100%] Success")
+                return get
+            except:
+                return '\033[91mUnknown error\x1B[37m'
     def post(*args, **kwargs):
-        if anon == "tor":
+        if anon == "tor" or anon == "web":
+            if anon == "web":
+               print("Web method not supported on POST, only for the GET method")
             if log:
                 print("[1%] Connecting to pluggable")
                 print("[4%] Importing tor client")
@@ -387,7 +444,9 @@ class inquiry:
                  except:
                      return '\033[91m403 Website refused to connect\x1B[37m'
     def put(*args, **kwargs):
-        if anon == "tor":
+        if anon == "tor" or anon == "web":
+            if anon == "web":
+               print("Web method not supported on POST, only for the GET method")
             if log:
                 print("[1%] Connecting to pluggable")
                 print("[4%] Importing tor client")
@@ -477,7 +536,9 @@ class inquiry:
                  except:
                      return '\033[91m403 Website refused to connect\x1B[37m'
     def delete(*args, **kwargs):
-        if anon == "tor":
+        if anon == "tor" or anon == "web":
+            if anon == "web":
+               print("Web method not supported on POST, only for the GET method")
             if log:
                 print("[1%] Connecting to pluggable")
                 print("[4%] Importing tor client")
@@ -567,7 +628,9 @@ class inquiry:
                  except:
                      return '\033[91m403 Website refused to connect\x1B[37m'
     def head(*args, **kwargs):
-        if anon == "tor":
+        if anon == "tor" or anon == "web":
+            if anon == "web":
+               print("Web method not supported on POST, only for the GET method")
             if log:
                 print("[1%] Connecting to pluggable")
                 print("[4%] Importing tor client")
@@ -670,6 +733,9 @@ class inquiry:
        elif type == "tor" or type == "TOR" or type == "Tor":
            anon = "tor"
            return "Using: tor"
+       elif type == "web" or type == "WEB" or type == "Web":
+           anon = "web"
+           return "Using: web"
        else:
            anon = "tor"
-           return "Unknown type: "+type+", defaul tor"
+           return "Unknown type: "+type+", default tor"
